# divyaj_psee
This code is used to connect to HDFS, it is built specifically for psee analytics team in Abbvie

 - The functions under this module:
        read_pickle(name), write_pickle(dataframe, name)

## refer docstrings for better understanding
